pro ColorBarSmooth,xleft,xright,ybot,ytop,level,labelstep,title,charsize=charsize
; Makes a color bar to put on a contour plot
; I usually make the contour xrange a little bigger on 1 side and
; put the color bar inside the plot boundaries

; xleft: color bar left side in data coordinates
; xright: color bar right side in data coordinates, the test is to the right
; of this so leave space
; ybot: bottom coordinate of color bar
; ytop: top coordinate of color bar, leave a little space for the title
; level: levels used in the contour program. (e.g. level=findgen(29)*5+100)
; label step: step size between labeled colors. This program assumes the
; levels are linear and puts labels at level[0]+i*labelstep
; Labelstep needs to divide evenly into max(level)-min(level)
; Title: text string to put on top of colorbar (e.g. "T (K)"), should be short


levdiff=max(level)-min(level)
ctx=[xleft,xright,xright,xleft,xleft] ;x-coord for polygon box
xdiff=xright-xleft
ydiff=ytop-ybot
nlev=fix((max(level)-min(level))/labelstep)
;cty=[0,0,1.0,1.0]*ydiff/levdiff*labelstep ;y-coord for polygon box
cty=[-.5,-.5,0.5,0.5]*ydiff/256.0 ;Plot all 256 colors
;for i=0,nlev-1 do polyfill,ctx,cty+ydiff/levdiff*labelstep*i+ybot,color=i*256.0/nlev ; Plot 1 color for each labelstep
for i=0,255 do polyfill,ctx,cty+ydiff/256.0*i+ybot,color=i,/normal ;Plot all 256 colors
plots,ctx,[ybot,ybot,ytop,ytop,ybot],/normal ; Draw line around color bar

If Fix(labelstep) eq labelstep then begin
    for j=0,nlev do xyouts,xright+xdiff*0.3,(j*labelstep)/levdiff*ydiff+ybot,strtrim(fix(j*labelstep+level[0]),2),charsize=1.2,/normal,charthick=1.5 ; Print labels
endif else begin
    n=0
    While (fix(labelstep*10^n) ne labelstep*10^n) do n=n+1
    for j=0,nlev do begin
       colorlabel=String(format='(f'+StrCompress(n+3,/Remove_All)+'.'+StrCompress(n,/Remove_All)+')',j*labelstep+level[0])
       xyouts,xright+xdiff*0.3,(j*labelstep)/levdiff*ydiff+ybot,colorlabel,charsize=3.5,/normal, charthick=3.5; Print labels
    endfor
endelse

xyouts,xright+xdiff*0.01,ytop+ydiff*0.04,title ,charsize=1.6,/normal, charthick=2.5; Print title
;stop
return
end
